// Generated by CoffeeScript 1.8.0
(function() {
  define(['chai', 'backbone', 'backbone-dom-view'], function(_arg, Backbone, DomView) {
    var expect, model;
    expect = _arg.expect;
    model = null;
    beforeEach(function() {
      return model = new Backbone.Model();
    });
    return describe('each helper', function() {
      it('should create view for each item in collection', function() {
        var ListView, View, el, list, listView;
        View = DomView.extend({
          tagName: 'li',
          template: {
            '': {
              html: '@name'
            }
          }
        });
        ListView = DomView.extend({
          tagName: 'ul',
          template: {
            '': {
              each: {
                view: View
              }
            }
          }
        });
        list = new Backbone.Collection([
          {
            name: 'Jack'
          }, {
            name: 'Bob'
          }
        ]);
        listView = new ListView({
          model: list
        });
        el = listView.$el;
        expect(el.find('li').length).to.equal(2);
        list.add({
          name: 'Max'
        });
        expect(el.find('li').length).to.equal(3);
        list.at(1).destroy();
        return expect(el).to.have.text('JackMax');
      });
      it('should run custom view function', function() {
        var DivView, LiView, ListView, el, list, listView;
        LiView = DomView.extend({
          tagName: 'li'
        });
        DivView = DomView.extend({
          tagName: 'div'
        });
        ListView = DomView.extend({
          tagName: 'ul',
          template: {
            '': {
              each: {
                view: function(model) {
                  if (model.get('type') === 'li') {
                    return LiView;
                  } else {
                    return DivView;
                  }
                }
              }
            }
          }
        });
        list = new Backbone.Collection([
          {
            type: 'li'
          }, {
            type: 'div'
          }
        ]);
        listView = new ListView({
          model: list
        });
        el = listView.$el;
        expect(el.find('li').length).to.be.equal(1);
        return expect(el.find('div').length).to.be.equal(1);
      });
      it('should run custom insertion/remove function', function() {
        var ListView, View, el, list, listView;
        View = DomView.extend({
          tagName: 'li',
          template: {
            '': {
              html: '@name'
            }
          }
        });
        ListView = DomView.extend({
          tagName: 'ul',
          template: {
            '': {
              each: {
                view: View,
                addHandler: 'prepend',
                delHandler: function(ul, view) {
                  expect(this).to.be.instanceOf(ListView);
                  return expect(view).to.be.instanceOf(View);
                }
              }
            }
          }
        });
        list = new Backbone.Collection([
          {
            name: 'Jack'
          }, {
            name: 'Bob'
          }
        ]);
        listView = new ListView({
          model: list
        });
        el = listView.$el;
        expect(el).to.have.text('BobJack');
        list.at(0).destroy();
        return expect(el).to.have.text('BobJack');
      });
      it('should create view with el:', function() {
        var ListView, View, el, list, listView;
        View = DomView.extend({
          template: {
            '': {
              html: '@name'
            }
          }
        });
        ListView = DomView.extend({
          el: $('<ul><li class="test"></li></ul>'),
          template: {
            '': {
              each: {
                view: View,
                el: '> *'
              }
            }
          }
        });
        list = new Backbone.Collection();
        listView = new ListView({
          model: list
        });
        el = listView.$el;
        expect(el.find('li').length).to.equal(0);
        list.set([
          {
            name: 'Jack'
          }, {
            name: 'Bob'
          }
        ]);
        expect(el.find('li').length).to.equal(2);
        return expect(el.find('li')).to.have["class"]('test');
      });
      return it('should have `parent` field', function() {
        var ListView, list, listView, views;
        views = [];
        ListView = DomView.extend({
          el: $('<ul></ul>'),
          template: {
            '': {
              each: {
                view: function(model) {
                  var view;
                  view = new Backbone.View({
                    model: model
                  });
                  if (model.get('parent')) {
                    view.parent = true;
                  }
                  views.push(view);
                  return view;
                }
              }
            }
          }
        });
        list = new Backbone.Collection([
          {
            parent: false
          }, {
            parent: true
          }
        ]);
        listView = new ListView({
          model: list
        });
        expect(views[0].parent).to.be.equal(listView);
        return expect(views[1].parent).to.be.equal(true);
      });
    });
  });

}).call(this);
